mod components;
mod map;
mod plugins;
mod resources;
mod systems;

mod prelude {
    pub use crate::components::*;
    pub use crate::map::*;
    pub use crate::plugins::*;
    pub use crate::resources::*;
    pub use crate::systems::*;
    pub use bevy::{
        diagnostic::{FrameTimeDiagnosticsPlugin, LogDiagnosticsPlugin},
        prelude::*,
    };

    pub const MAP_WIDTH: i32 = 80;
    pub const MAP_HEIGHT: i32 = 50;
    pub const CELL_SIZE: i32 = 64;
    pub const NUM_TILES: usize = (MAP_WIDTH * MAP_HEIGHT) as usize;
}

use prelude::*;

fn main() {
    App::build()
        .insert_resource(ClearColor(Color::rgb(0.0, 0.0, 0.0)))
        .init_resource::<Map>()
        .add_plugins(DefaultPlugins)
        //.add_plugin(FrameTimeDiagnosticsPlugin)
        //.add_plugin(LogDiagnosticsPlugin)
        //.add_plugin(bevy::asset::diagnostic::AssetCountDiagnosticsPlugin::< ColorMaterial>)
        .add_startup_system(setup.system())
        .add_startup_system(add_player.system())
        .add_system(player_movement.system())
        .add_system(follow_player.system())
        .run();
}
